{ pkgs ? import <nixpkgs> {},
}:

let
  src = builtins.filterSource (path: type:
    !builtins.elem (baseNameOf path) [
      "target"
      "default.nix"
      "shell.nix"
      "nixos-module.nix"
    ]
  ) ./.;
  build = { pname, cargoSha256 }: pkgs.rustPlatform.buildRustPackage {
    inherit pname cargoSha256 src;
    version = "0.1.0";
    nativeBuildInputs = with pkgs; [ pkg-config ];
    buildInputs = with pkgs; [
      openssl
      postgresql.lib
    ];
    preBuild = "pushd ${pname}";
    postBuild = "popd";
  };
in {
  ticker-update = build {
    pname = "ticker-update";
    cargoSha256 = "11xygn7dqqyaw5h2g1pb7759f8n9fcyxljw36hhbgim4hz5pn8b0";
  };
  ticker-serve = (build {
    pname = "ticker-serve";
    cargoSha256 = "02cvrqd5p2h8hy5jvkj4d35iqlpa1xqj7blg6lyd7w42ajdc250v";
  }).overrideAttrs (oa: {
    postBuild = ''
      ${oa.postBuild}

      mkdir -p $out/shared/libticker $out/shared/ticker-serve
      cp -ar ticker-serve/static $out/shared/ticker-serve/
      cp -ar schema.sql $out/shared/libticker/
    '';
  });
}
